<?php
// $Id: menucontent.php,v 1.10 2003/11/24 23:28:45 rcastley Exp $
/**
* Content Button Bar HTML
* @package Mambo Open Source
* @Copyright (C) 2000 - 2003 Miro International Pty Ltd
* @ All rights reserved
* @ Mambo Open Source is Free Software
* @ Released under GNU/GPL License : http://www.gnu.org/copyleft/gpl.html
* @version $Revision: 1.10 $
**/

class menucontent {
	function NEW_MENU() {
		mosMenuBar::startTable();
		mosMenuBar::preview( 'contentwindow' );
		mosMenuBar::divider();
		mosMenuBar::save();
		mosMenuBar::divider();
		mosMenuBar::media_manager();
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function EDIT_MENU( $state ) {
		mosMenuBar::startTable();
		if ($state == 0) {
			mosMenuBar::publish();
		} else {
			mosMenuBar::unpublish();
		}
		mosMenuBar::divider();
		mosMenuBar::preview( 'contentwindow' );
		mosMenuBar::divider();
		mosMenuBar::save();
		mosMenuBar::divider();
		mosMenuBar::media_manager();
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function ARCHIVE_MENU() {
		mosMenuBar::startTable();
		mosMenuBar::unarchiveList();
		mosMenuBar::divider();
		mosMenuBar::addNew();
		mosMenuBar::deleteList();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function MOVE_MENU() {
		mosMenuBar::startTable();
		mosMenuBar::custom( 'movesectsave', 'save.png', 'save_f2.png', '&nbsp;Save', false );
		mosMenuBar::divider();
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function DEFAULT_MENU() {
		mosMenuBar::startTable();
		mosMenuBar::publishList();
		mosMenuBar::unpublishList();
		mosMenuBar::archiveList();
		mosMenuBar::divider();
		mosMenuBar::addNew();
		mosMenuBar::editList();
		mosMenuBar::deleteList();
		mosMenuBar::custom( 'movesect', 'move.png', 'move_f2.png', '&nbsp;Move' );
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
}
?>
